window.Gleam.initSearch([{"doc":"zeptomail","title":"zeptomail","content":"# zeptomail\n\n[![Package Version](https://img.shields.io/hexpm/v/zeptomail)](https://hex.pm/packages/zeptomail)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/zeptomail/)\n\nA wrapper for [ZeptoMail&#39;s transactional email API](https://www.zoho.com/zeptomail/).\n\n\n## Usage\n\nAdd this package to your Gleam project:\n\n```sh\ngleam add zeptomail\n```\n\nAnd then send some email!\n\n```gleam\nimport gleam/httpc\nimport zeptomail.{Addressee}\n\npub fn main() {\n  let key = &quot;your-api-key-here&quot;\n\n  // Create an email to send\n  let email = zeptomail.Email(\n    from: [Addressee(&quot;Mike&quot;, &quot;mike@example.com&quot;)],\n    to: Addressee(&quot;Joe&quot;, &quot;joe@example.com&quot;),\n    reply_to: [],\n    cc: [Addressee(&quot;Robert&quot;, &quot;robert@example.com&quot;)],\n    bcc: [],\n    body: zeptomail.TextBody(&quot;Hello, Mike!&quot;),\n    subject: &quot;Hello, Joe!&quot;,\n  )\n\n  // Prepare an API request that sends the email\n  let request = zeptomail.email_request(email, key)\n\n  // Send the API request using `gleam_httpc`\n  let assert Ok(response) = httpc.send(request)\n\n  // Parse the API response to verify success\n  let assert Ok(data) = zeptomail.decode_email_response(response)\n}\n```\n","url":"index.html"},{"doc":"zeptomail","title":"Addressee","content":"pub type Addressee {\n  Addressee(name: String, address: String)\n}\n\nAddressee(name: String, address: String)\n\n\nSynonyms:\nzeptomail.Addressee\nzeptomail Addressee","url":"zeptomail.html#Addressee"},{"doc":"zeptomail","title":"ApiData","content":"pub type ApiData {\n  ApiData(\n    object: String,\n    request_id: String,\n    message: String,\n    data: List(ApiDatum),\n  )\n}\n\nApiData(\n  object: String,\n  request_id: String,\n  message: String,\n  data: List(ApiDatum),\n)\n\n\nSynonyms:\nzeptomail.ApiData\nzeptomail ApiData","url":"zeptomail.html#ApiData"},{"doc":"zeptomail","title":"ApiDatum","content":"pub type ApiDatum {\n  ApiDatum(code: String, message: String)\n}\n\nApiDatum(code: String, message: String)\n\n\nSynonyms:\nzeptomail.ApiDatum\nzeptomail ApiDatum","url":"zeptomail.html#ApiDatum"},{"doc":"zeptomail","title":"ApiError","content":"pub type ApiError {\n  ApiError(\n    code: String,\n    message: String,\n    details: List(ApiErrorDetail),\n  )\n  UnexpectedResponse(json.DecodeError)\n}\n An error returned by the ZeptoMail API.\n The possible error codes are documented here:\n &lt;https://www.zoho.com/zeptomail/help/api/error-codes.html&gt;\n\nApiError(\n  code: String,\n  message: String,\n  details: List(ApiErrorDetail),\n)\n\n\nUnexpectedResponse(json.DecodeError)\n\n\nSynonyms:\nzeptomail.ApiError\nzeptomail ApiError","url":"zeptomail.html#ApiError"},{"doc":"zeptomail","title":"ApiErrorDetail","content":"pub type ApiErrorDetail {\n  ApiErrorDetail(\n    code: String,\n    message: String,\n    target: Option(String),\n    target_value: Option(String),\n  )\n}\n\nApiErrorDetail(\n  code: String,\n  message: String,\n  target: Option(String),\n  target_value: Option(String),\n)\n\n\nSynonyms:\nzeptomail.ApiErrorDetail\nzeptomail ApiErrorDetail","url":"zeptomail.html#ApiErrorDetail"},{"doc":"zeptomail","title":"Body","content":"pub type Body {\n  TextBody(content: String)\n  HtmlBody(content: String)\n}\n\nTextBody(content: String)\n\n\nHtmlBody(content: String)\n\n\nSynonyms:\nzeptomail.Body\nzeptomail Body","url":"zeptomail.html#Body"},{"doc":"zeptomail","title":"Email","content":"pub type Email {\n  Email(\n    from: Addressee,\n    to: List(Addressee),\n    cc: List(Addressee),\n    bcc: List(Addressee),\n    reply_to: List(Addressee),\n    body: Body,\n    subject: String,\n  )\n}\n\nEmail(\n  from: Addressee,\n  to: List(Addressee),\n  cc: List(Addressee),\n  bcc: List(Addressee),\n  reply_to: List(Addressee),\n  body: Body,\n  subject: String,\n)\n\n\nSynonyms:\nzeptomail.Email\nzeptomail Email","url":"zeptomail.html#Email"},{"doc":"zeptomail","title":"decode_email_response","content":"pub fn decode_email_response(\n  response: Response(String),\n) -&gt; Result(ApiData, ApiError)\n Create a HTTP request to send an email via the ZeptoMail API\nSynonyms:\nzeptomail.decode_email_response\nzeptomail decode_email_response","url":"zeptomail.html#decode_email_response"},{"doc":"zeptomail","title":"email_request","content":"pub fn email_request(\n  email: Email,\n  api_token: String,\n) -&gt; Request(String)\n Create a HTTP request to send an email via the ZeptoMail API\nSynonyms:\nzeptomail.email_request\nzeptomail email_request","url":"zeptomail.html#email_request"},{"doc":"zeptomail","title":"zeptomail","content":"","url":"zeptomail.html"}]);